import { reactive } from 'vue'
import themeVariables from '../assets/styles/themes/index.js'
import { toggleThemeColorClass, toggleThemeClass } from '../utils'
import CachedViewAction from './modules/cached-view'
import VisitedViewAction from './modules/visited-view'
const layoutModes = ['ltr', 'lcr', 'ttb']

export default {
  state: reactive({
    isCollapse: false,
    isFixedNavBar: true,
    layoutMode: 'ltr',
    device: 'pc',
    theme: 'light',
    themeColor: 'theme_color_blue',
    themeVariables,
    permissionRoutes: [],
    visitedView: [],
    cachedView: [],
    userInfo: {
      nickName: '',
      avatar: ''
    },
    actionItem: {
      showSearch: true,
      showMessage: true,
      showFullScreen: true,
      showRefresh: true
    }
  }),
  start({ state, actions }) {
    state && (this.state = Object.assign(this.state, state))
    if (actions) {
      for (const key in actions) {
        this[key] = actions[key]
      }
    }
    toggleThemeColorClass(document.body, this.state.themeColor)
    toggleThemeClass(document.body, this.state.theme)
  },
  randomLayouMode() {
    return layoutModes[Math.floor(Math.random() * layoutModes.length)]
  },
  toggleCollapse(newStatus) {
    this.state.isCollapse = newStatus
  },
  toggleFixedNavBar(newStatus) {
    this.state.isFixedNavBar = newStatus
  },
  changeLayoutMode(mode = 'ltr') {
    this.state.layoutMode = mode
  },
  changeDevice(device = 'pc') {
    this.state.device = device
  },
  changeTheme(theme = 'dark') {
    this.state.theme = theme
  },
  isShowHeader() {
    return this.state.device === 'pc' && this.state.layoutMode === 'ttb'
  },
  getSplitTabs() {
    return this.state.permissionRoutes.filter(it => {
      return it.path && !it.hidden && it.children && it.children.length > 0
    })
  },
  initPermissionRoute(routes) {
    this.state.permissionRoutes = routes
  },
  isEmptyPermissionRoute() {
    return !this.state.permissionRoutes || this.state.permissionRoutes.length === 0
  },
  setUserInfo(userInfo) {
    this.state.userInfo.nickName = userInfo ? userInfo.nickName || '' : ''
    this.state.userInfo.avatar = userInfo ? userInfo.avatar || '' : ''
  },
  reset() {
    this.state = reactive({
      isCollapse: false,
      isFixedNavBar: true,
      layoutMode: 'ltr',
      device: 'pc',
      theme: 'light',
      themeColor: 'theme_color_blue',
      themeVariables,
      permissionRoutes: [],
      visitedView: [],
      cachedView: [],
      userInfo: {
        nickName: '',
        avatar: ''
      },
      actionItem: {
        showSearch: true,
        showMessage: true,
        showFullScreen: true,
        showRefresh: true
      }
    })
  },
  ...CachedViewAction,
  ...VisitedViewAction
}
